aboutsummaryrefslogtreecommitdiffstats
path: root/src/ui/KeyUploadDialog.h
diff options
context:
space:
mode:
Diffstat (limited to '')
-rw-r--r--src/ui/KeyUploadDialog.h (renamed from include/ui/KeyUploadDialog.h)40
1 files changed, 20 insertions, 20 deletions
diff --git a/include/ui/KeyUploadDialog.h b/src/ui/KeyUploadDialog.h
index b41ced6b..b607c321 100644
--- a/include/ui/KeyUploadDialog.h
+++ b/src/ui/KeyUploadDialog.h
@@ -1,7 +1,7 @@
/**
* This file is part of GPGFrontend.
*
* GPGFrontend is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
@@ -25,33 +25,33 @@
#ifndef GPGFRONTEND_KEYUPLOADWIDGET_H
#define GPGFRONTEND_KEYUPLOADWIDGET_H
-#include "GpgFrontend.h"
#include "gpg/GpgContext.h"
+#include "ui/GpgFrontendUI.h"
-class KeyUploadDialog : public QDialog {
-Q_OBJECT
-public:
- KeyUploadDialog(GpgME::GpgContext *ctx, const QVector<GpgKey> &keys, QWidget *parent = nullptr);
-
-public slots:
+namespace GpgFrontend::UI {
- void slotUpload();
+class KeyUploadDialog : public QDialog {
+ Q_OBJECT
+ public:
+ explicit KeyUploadDialog(const KeyIdArgsListPtr& keys_ids, QWidget* parent);
-private slots:
+ public slots:
- void uploadKeyToServer(QByteArray &keys);
+ void slotUpload();
- void slotUploadFinished();
+ private slots:
-private:
+ void uploadKeyToServer(const GpgFrontend::ByteArray& keys_data);
- GpgME::GpgContext *mCtx;
- const QVector<GpgKey> &mKeys;
- QString appPath;
- QSettings settings;
- QByteArray mKeyData;
+ void slotUploadFinished();
+ private:
+ QString appPath;
+ QSettings settings;
+ KeyListPtr mKeys;
+ QByteArray mKeyData;
};
+} // namespace GpgFrontend::UI
-#endif //GPGFRONTEND_KEYUPLOADWIDGET_H
+#endif // GPGFRONTEND_KEYUPLOADWIDGET_H
@@ -1,7 +1,7 @@
/**
- * This file is part of GPGFrontend.
+ * This file is part of GpgFrontend.
*
@@ -1,7 +1,7 @@
*
- * GPGFrontend is free software: you can redistribute it and/or modify
+ * GpgFrontend is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or